from abc import ABC, abstractmethod
from typing import Dict, List

from asset_discovery.models import Asset, AssetIdentification, AssetUpdate


class DataStore(ABC):
    def __init__(self, json_provider):
        self._json_provider = json_provider

    @abstractmethod
    def list(self) -> List[Asset]:
        pass

    @abstractmethod
    def get_identification_to_entry(self) -> Dict[AssetIdentification, Asset]:
        pass

    @abstractmethod
    def add(self, entry: Asset):
        pass

    @abstractmethod
    def add_many(self, entries: List[Asset]):
        pass

    @abstractmethod
    def remove(self, identification: AssetIdentification):
        pass

    @abstractmethod
    def remove_all(self):
        pass

    @abstractmethod
    def update(self, update_data: AssetUpdate, source_props_only=False):
        pass

    @abstractmethod
    def update_many(self, updates: List[AssetUpdate], source_props_only=False):
        pass
